#ifndef LOAD_GENERATOR
#define LOAD_GENERATOR

#include "./Common.pml"

#ifdef CYCLIC

/**
 * Updates a single data point. The values will be cycled using the array
 * dataPointValues.
 */
inline updateOne(k, z)
{
  d_step
  {
    inputDataPoints[k] = SERVICE_COUNT * z + k + 1;
    if
      :: k + 1 >= SERVICE_COUNT ->
	 k = 0;
	 INCREMENT(z, 3)
      :: else ->
	 k = k + 1;
    fi
  }
}

/**
 * This process generates update events to data points. Index z is used for
 * cycling between the pre-computed (in Model.pml) update values.
 */
proctype LoadGenerator()
{
  byte k;
  byte z;
end_update: do
    :: updateOne(k, z)
  od
}

#else

/**
 * Updates a single data point.
 */
inline updateOne(k)
{
  d_step
  {
    /* TODO: Choosing k non-deterministically would be more realistic. */
    inputDataPoints[k] = inputDataPoints[k] + SERVICE_COUNT;
    INCREMENT(k, SERVICE_COUNT)
  }
}

/**
 * Prints the final contents of the input array.
 */
inline printInputs(k)
{
  d_step
  {
    printf("The final DIM inputs:\n");
    for (k : 0 .. SERVICE_COUNT - 1)
    {
      printf("%d:\t%d\n", k, inputDataPoints[k]);
    }
    end = true
  }
}

/**
 * This process generates update events to data points. Index z runs over events
 * while index k runs over data points (i.e. services). When all events have
 * been generated, this process halts.
 */
proctype LoadGenerator()
{
  byte k;
  byte z;
  for (z : 0 .. EVENT_COUNT - 1)
  {
    updateOne(k)
  }
  printInputs(k)
}
#endif

#endif /* LOAD_GENERATOR */