#!/bin/bash
if [ -z "$1" ] || [ -z "$2" ] || [ -z "$3" ]; then
    echo "Usage: run.sh [version] [event count] [property] {cyclic}";
    exit 0;
fi

params="-DNDEBUG -DEVENT_COUNT=$2"
property="ec-$2"
command=""
case "$3" in
    "none" )
	params="$params -DOMIT_THEORY";
        command="./pan -m10000000" ;;
    "availability" )
        params="$params -DAVAILABILITY";
        property="availability-$property";
	command="./pan -a -m10000000" ;;
    * )
        params="$params -DREACH";
        property="$3-$property";
	command="make $3";;
esac
if [ -n "$4" ]; then
    params="$params -DCYCLIC"
    property="$property-cyclic"
fi
directory="results/$property"
echo "$params" > params;
mkdir -p "$directory"

variants=(inputArrays \
	  inputCounters \
	  directInput \
	  directInputCounters \
	  inputPairs \
	  inputOutputPairs \
	  inputOutputPairs-inputChannels \
	  inputOutputPairsAndChannels)

for variant in ${variants[*]}; do
    echo "---------------------------------------------------------------------\
-----------"
    echo "Processing $variant with EC $2 and property \"$3...\""
    make clean
    if git checkout "$variant-$1"; then
	make pan;
	filename="$variant-$1-$property.txt";
	/appl/opt/time/1.9/bin/time -v \
	    timeout --signal=2 --kill-after=5m 60m $command |& \
	    tee "$directory/$filename" | \
	    grep -E "^[^(Depth=)]";
    fi
done
